@@ -16,32 +16,28 @@ import io
 
 from M2Crypto import BIO, Err, X509, m2, util  # noqa
 from M2Crypto.SSL import Checker, Context, timeout  # noqa
-from M2Crypto.SSL import SSLError
 from M2Crypto.SSL.Cipher import Cipher, Cipher_Stack
 from M2Crypto.SSL.Session import Session
 from typing import (
-    Any,
-    AnyStr,
     Callable,
     Optional,
     Tuple,
     Union,
-)  # noqa
+)
 
 __all__ = [
     'Connection',
-    'timeout',  # XXX Not really, but for documentation purposes
+    'timeout',
 ]
 
 log = logging.getLogger(__name__)
 
 
-def _serverPostConnectionCheck(*args, **kw):
-    # type: (*Any, **Any) -> int
+def _serverPostConnectionCheck(*args, **kw) -> int:
     return 1
 
 
-class Connection(object):
+class Connection:
     """An SSL connection."""
 
     serverPostConnectionCheck = _serverPostConnectionCheck
@@ -50,8 +46,12 @@ class Connection(object):
     m2_ssl_free = m2.ssl_free
     m2_bio_noclose = m2.bio_noclose
 
-    def __init__(self, ctx, sock=None, family=socket.AF_INET):
-        # type: (Context, Optional[socket.socket], int) -> None
+    def __init__(
+        self,
+        ctx: Context,
+        sock: Optional[socket.socket] = None,
+        family: int = socket.AF_INET,
+    ) -> None:
         """
 
         :param ctx: SSL.Context
@@ -64,7 +64,7 @@ class Connection(object):
 
         self._bio_freed = False
         self.ctx = ctx
-        self.ssl = m2.ssl_new(self.ctx.ctx)  # type: bytes
+        self.ssl: bytes = m2.ssl_new(self.ctx.ctx)
         if sock is not None:
             self.socket = sock
         else:
@@ -85,7 +85,7 @@ class Connection(object):
                 self.ctx.post_connection_check
             )
 
-        self.host = None
+        self.host: Optional[bytes] = None
 
     def _free_bio(self):
         """
@@ -105,8 +105,7 @@ class Connection(object):
             self.socket.close()
             self._bio_freed = True
 
-    def __del__(self):
-        # type: () -> None
+    def __del__(self) -> None:
         # Notice that M2Crypto doesn't automatically shuts down the
         # connection here. You have to call self.close() in your
         # program, M2Crypto won't do it automatically for you.
@@ -120,8 +119,7 @@ class Connection(object):
             self.m2_ssl_free(self.ssl)
         self.socket.close()
 
-    def close(self, freeBio=False):
-        # type: (Optional[bool]) -> None
+    def close(self, freeBio: Optional[bool] = False) -> None:
         """
         if freeBio is true, call _free_bio
         """
@@ -129,8 +127,7 @@ class Connection(object):
         if freeBio:
             self._free_bio()
 
-    def clear(self):
-        # type: () -> int
+    def clear(self) -> int:
         """
         If there were errors in this connection, call clear() rather
         than close() to end it, so that bad sessions will be cleared
@@ -138,8 +135,7 @@ class Connection(object):
         """
         return m2.ssl_clear(self.ssl)
 
-    def set_shutdown(self, mode):
-        # type: (int) -> None
+    def set_shutdown(self, mode: int) -> None:
         """Sets the shutdown state of the Connection to mode.
 
         The shutdown state of an ssl connection is a bitmask of (use
@@ -163,25 +159,20 @@ class Connection(object):
         """
         m2.ssl_set_shutdown1(self.ssl, mode)
 
-    def get_shutdown(self):
-        # type: () -> None
+    def get_shutdown(self) -> None:
         """Get the current shutdown mode of the Connection."""
         return m2.ssl_get_shutdown(self.ssl)
 
-    def bind(self, addr):
-        # type: (util.AddrType) -> None
+    def bind(self, addr: util.AddrType) -> None:
         self.socket.bind(addr)
 
-    def listen(self, qlen=5):
-        # type: (int) -> None
+    def listen(self, qlen: int = 5) -> None:
         self.socket.listen(qlen)
 
-    def ssl_get_error(self, ret):
-        # type: (int) -> int
+    def ssl_get_error(self, ret: int) -> int:
         return m2.ssl_get_error(self.ssl, ret)
 
-    def set_bio(self, readbio, writebio):
-        # type: (BIO.BIO, BIO.BIO) -> None
+    def set_bio(self, readbio: BIO.BIO, writebio: BIO.BIO) -> None:
         """Explicitly set read and write bios
 
         Connects the BIOs for the read and write operations of the
@@ -200,8 +191,9 @@ class Connection(object):
         """
         m2.ssl_set_bio(self.ssl, readbio._ptr(), writebio._ptr())
 
-    def set_client_CA_list_from_file(self, cafile):
-        # type: (AnyStr) -> None
+    def set_client_CA_list_from_file(
+        self, cafile: Union[str, bytes]
+    ) -> None:
         """Set the acceptable client CA list.
 
         If the client returns a certificate, it must have been issued by
@@ -220,8 +212,7 @@ class Connection(object):
         """
         m2.ssl_set_client_CA_list_from_file(self.ssl, cafile)
 
-    def set_client_CA_list_from_context(self):
-        # type: () -> None
+    def set_client_CA_list_from_context(self) -> None:
         """
         Set the acceptable client CA list. If the client
         returns a certificate, it must have been issued by
@@ -231,12 +222,10 @@ class Connection(object):
         """
         m2.ssl_set_client_CA_list_from_context(self.ssl, self.ctx.ctx)
 
-    def setup_addr(self, addr):
-        # type: (util.AddrType) -> None
+    def setup_addr(self, addr: util.AddrType) -> None:
         self.addr = addr
 
-    def set_ssl_close_flag(self, flag):
-        # type: (int) -> None
+    def set_ssl_close_flag(self, flag: int) -> None:
         """
         By default, SSL struct will be freed in __del__. Call with
         m2.bio_close to override this default.
@@ -249,8 +238,7 @@ class Connection(object):
             )
         self.ssl_close_flag = flag
 
-    def setup_ssl(self):
-        # type: () -> None
+    def setup_ssl(self) -> None:
         # Make a BIO_s_socket.
         self.sockbio = m2.bio_new_socket(self.socket.fileno(), 0)
         # Link SSL struct with the BIO_socket.
@@ -260,19 +248,16 @@ class Connection(object):
         # Link BIO_f_ssl with the SSL struct.
         m2.bio_set_ssl(self.sslbio, self.ssl, m2.bio_noclose)
 
-    def _setup_ssl(self, addr):
-        # type: (util.AddrType) -> None
+    def _setup_ssl(self, addr: util.AddrType) -> None:
         """Deprecated"""
         self.setup_addr(addr)
         self.setup_ssl()
 
-    def set_accept_state(self):
-        # type: () -> None
+    def set_accept_state(self) -> None:
         """Sets Connection to work in the server mode."""
         m2.ssl_set_accept_state(self.ssl)
 
-    def accept_ssl(self):
-        # type: () -> Optional[int]
+    def accept_ssl(self) -> Optional[int]:
         """Waits for a TLS/SSL client to initiate the TLS/SSL handshake.
 
         The communication channel must already have been set and
@@ -296,8 +281,7 @@ class Connection(object):
         """
         return m2.ssl_accept(self.ssl, self._timeout)
 
-    def accept(self):
-        # type: () -> Tuple[Connection, util.AddrType]
+    def accept(self) -> Tuple[object, util.AddrType]:
         """Accept an SSL connection.
 
         The return value is a pair (ssl, addr) where ssl is a new SSL
@@ -328,17 +312,14 @@ class Connection(object):
                 )
         return ssl, addr
 
-    def set_connect_state(self):
-        # type: () -> None
+    def set_connect_state(self) -> None:
         """Sets Connection to work in the client mode."""
         m2.ssl_set_connect_state(self.ssl)
 
-    def connect_ssl(self):
-        # type: () -> Optional[int]
+    def connect_ssl(self) -> Optional[int]:
         return m2.ssl_connect(self.ssl, self._timeout)
 
-    def connect(self, addr):
-        # type: (util.AddrType) -> int
+    def connect(self, addr: util.AddrType) -> int:
         """Overloading socket.connect()
 
         :param addr: addresses have various depending on their type
@@ -365,42 +346,34 @@ class Connection(object):
                 )
         return ret
 
-    def shutdown(self, how):
-        # type: (int) -> None
+    def shutdown(self, how: int) -> None:
         m2.ssl_set_shutdown(self.ssl, how)
 
-    def renegotiate(self):
-        # type: () -> int
+    def renegotiate(self) -> int:
         """Renegotiate this connection's SSL parameters."""
         return m2.ssl_renegotiate(self.ssl)
 
-    def pending(self):
-        # type: () -> int
+    def pending(self) -> int:
         """Return the numbers of octets that can be read from the connection."""
         return m2.ssl_pending(self.ssl)
 
-    def _write_bio(self, data):
-        # type: (bytes) -> int
+    def _write_bio(self, data: bytes) -> int:
         return m2.ssl_write(self.ssl, data, self._timeout)
 
-    def _write_nbio(self, data):
-        # type: (bytes) -> int
+    def _write_nbio(self, data: bytes) -> int:
         return m2.ssl_write_nbio(self.ssl, data)
 
-    def _read_bio(self, size=1024):
-        # type: (int) -> bytes
+    def _read_bio(self, size: int = 1024) -> bytes:
         if size <= 0:
             raise ValueError('size <= 0')
         return m2.ssl_read(self.ssl, size, self._timeout)
 
-    def _read_nbio(self, size=1024):
-        # type: (int) -> bytes
+    def _read_nbio(self, size: int = 1024) -> bytes:
         if size <= 0:
             raise ValueError('size <= 0')
         return m2.ssl_read_nbio(self.ssl, size)
 
-    def write(self, data):
-        # type: (bytes) -> int
+    def write(self, data: bytes) -> int:
         if self._timeout != 0.0:
             return self._write_bio(data)
         return self._write_nbio(data)
@@ -410,8 +383,9 @@ class Connection(object):
     def _decref_socketios(self):
         pass
 
-    def recv_into(self, buff, nbytes=0):
-        # type: (Union[bytearray, memoryview], int) -> int
+    def recv_into(
+        self, buff: Union[bytearray, memoryview], nbytes: int = 0
+    ) -> int:
         """
         A version of recv() that stores its data into a buffer
         rather than creating a new string.  Receive up to nbytes
@@ -447,16 +421,14 @@ class Connection(object):
 
         return buflen
 
-    def read(self, size=1024):
-        # type: (int) -> bytes
+    def read(self, size: int = 1024) -> bytes:
         if self._timeout != 0.0:
             return self._read_bio(size)
         return self._read_nbio(size)
 
     recv = read
 
-    def setblocking(self, mode):
-        # type: (int) -> None
+    def setblocking(self, mode: int) -> None:
         """Set this connection's underlying socket to _mode_.
 
         Set blocking or non-blocking mode of the socket: if flag is 0,
@@ -470,26 +442,25 @@ class Connection(object):
 
         :param mode: new mode to be set
         """
-        self.socket.setblocking(mode)
+        self.socket.setblocking(bool(mode))
         if mode:
             self._timeout = -1.0
         else:
             self._timeout = 0.0
 
-    def settimeout(self, timeout):
-        # type: (float) -> None
+    def settimeout(self, timeout: float) -> None:
         """Set this connection's underlying socket's timeout to _timeout_."""
         self.socket.settimeout(timeout)
         self._timeout = timeout
         if self._timeout is None:
             self._timeout = -1.0
 
-    def fileno(self):
-        # type: () -> int
+    def fileno(self) -> int:
         return self.socket.fileno()
 
-    def getsockopt(self, level, optname, buflen=None):
-        # type: (int, int, Optional[int]) -> Union[int, bytes]
+    def getsockopt(
+        self, level: int, optname: int, buflen: Optional[int] = None
+    ) -> Union[int, bytes]:
         """Get the value of the given socket option.
 
         :param level: level at which the option resides.
@@ -517,10 +488,17 @@ class Connection(object):
                  the optional built-in module struct for a way to decode
                  C structures encoded as byte strings).
         """
-        return self.socket.getsockopt(level, optname, buflen)
+        if buflen is None:
+            return self.socket.getsockopt(level, optname)
+        else:
+            return self.socket.getsockopt(level, optname, buflen)
 
-    def setsockopt(self, level, optname, value=None):
-        # type: (int, int, Union[int, bytes, None]) -> Optional[bytes]
+    def setsockopt(
+        self,
+        level: int,
+        optname: int,
+        value: Union[int, bytes, None] = None,
+    ) -> Optional[bytes]:
         """Set the value of the given socket option.
 
         :param level: same as with getsockopt() above
@@ -535,15 +513,18 @@ class Connection(object):
 
         :return: None for success or the error handler for failure.
         """
-        return self.socket.setsockopt(level, optname, value)
+        if value is None:
+            return self.socket.setsockopt(
+                level, optname, value, optlen
+            )
+        else:
+            return self.socket.setsockopt(level, optname, value)
 
-    def get_context(self):
-        # type: () -> Context
+    def get_context(self) -> Context:
         """Return the Context object associated with this connection."""
         return m2.ssl_get_ssl_ctx(self.ssl)
 
-    def get_state(self):
-        # type: () -> bytes
+    def get_state(self) -> bytes:
         """Return the SSL state of this connection.
 
         During its use, an SSL objects passes several states. The state
@@ -557,27 +538,22 @@ class Connection(object):
         """
         return m2.ssl_get_state(self.ssl)
 
-    def verify_ok(self):
-        # type: () -> bool
+    def verify_ok(self) -> bool:
         return m2.ssl_get_verify_result(self.ssl) == m2.X509_V_OK
 
-    def get_verify_mode(self):
-        # type: () -> int
+    def get_verify_mode(self) -> int:
         """Return the peer certificate verification mode."""
         return m2.ssl_get_verify_mode(self.ssl)
 
-    def get_verify_depth(self):
-        # type: () -> int
+    def get_verify_depth(self) -> int:
         """Return the peer certificate verification depth."""
         return m2.ssl_get_verify_depth(self.ssl)
 
-    def get_verify_result(self):
-        # type: () -> int
+    def get_verify_result(self) -> int:
         """Return the peer certificate verification result."""
         return m2.ssl_get_verify_result(self.ssl)
 
-    def get_peer_cert(self):
-        # type: () -> X509.X509
+    def get_peer_cert(self) -> X509.X509:
         """Return the peer certificate.
 
         If the peer did not provide a certificate, return None.
@@ -588,8 +564,7 @@ class Connection(object):
         # Need to free the pointer coz OpenSSL doesn't.
         return X509.X509(c, 1)
 
-    def get_peer_cert_chain(self):
-        # type: () -> Optional[X509.X509_Stack]
+    def get_peer_cert_chain(self) -> Optional[X509.X509_Stack]:
         """Return the peer certificate chain; if the peer did not provide
         a certificate chain, return None.
 
@@ -603,8 +578,7 @@ class Connection(object):
         # No need to free the pointer coz OpenSSL does.
         return X509.X509_Stack(c)
 
-    def get_cipher(self):
-        # type: () -> Optional[Cipher]
+    def get_cipher(self) -> Optional[Cipher]:
         """Return an M2Crypto.SSL.Cipher object for this connection; if the
         connection has not been initialised with a cipher suite, return None.
         """
@@ -613,8 +587,7 @@ class Connection(object):
             return None
         return Cipher(c)
 
-    def get_ciphers(self):
-        # type: () -> Optional[Cipher_Stack]
+    def get_ciphers(self) -> Optional[Cipher_Stack]:
         """Return an M2Crypto.SSL.Cipher_Stack object for this
         connection; if the connection has not been initialised with
         cipher suites, return None.
@@ -624,25 +597,23 @@ class Connection(object):
             return None
         return Cipher_Stack(c)
 
-    def get_cipher_list(self, idx=0):
-        # type: (int) -> str
+    def get_cipher_list(self, idx: int = 0) -> str:
         """Return the cipher suites for this connection as a string object."""
         return m2.ssl_get_cipher_list(self.ssl, idx)
 
-    def set_cipher_list(self, cipher_list):
-        # type: (str) -> int
+    def set_cipher_list(self, cipher_list: str) -> int:
         """Set the cipher suites for this connection."""
         return m2.ssl_set_cipher_list(self.ssl, cipher_list)
 
-    def makefile(self, mode='rb', bufsize=-1):
-        # type: (AnyStr, int) -> Union[io.BufferedRWPair,io.BufferedReader]
+    def makefile(
+        self, mode: Union[str, bytes] = 'rb', bufsize: int = -1
+    ) -> Union[io.BufferedRWPair, io.BufferedReader]:
         raw = socket.SocketIO(self, mode)
         if 'rw' in mode:
             return io.BufferedRWPair(raw, raw)
         return io.BufferedReader(raw, io.DEFAULT_BUFFER_SIZE)
 
-    def getsockname(self):
-        # type: () -> util.AddrType
+    def getsockname(self) -> util.AddrType:
         """Return the socket's own address.
 
         This is useful to find out the port number of an IPv4/v6 socket,
@@ -653,8 +624,7 @@ class Connection(object):
         """
         return self.socket.getsockname()
 
-    def getpeername(self):
-        # type: () -> util.AddrType
+    def getpeername(self) -> util.AddrType:
         """Return the remote address to which the socket is connected.
 
         This is useful to find out the port number of a remote IPv4/v6 socket,
@@ -665,27 +635,22 @@ class Connection(object):
         """
         return self.socket.getpeername()
 
-    def set_session_id_ctx(self, id):
-        # type: (bytes) -> int
+    def set_session_id_ctx(self, id: bytes) -> int:
         ret = m2.ssl_set_session_id_context(self.ssl, id)
         if not ret:
             raise SSLError(Err.get_error_message())
 
-    def get_session(self):
-        # type: () -> Session
+    def get_session(self) -> Session:
         sess = m2.ssl_get_session(self.ssl)
         return Session(sess)
 
-    def set_session(self, session):
-        # type: (Session) -> None
+    def set_session(self, session: Session) -> None:
         m2.ssl_set_session(self.ssl, session._ptr())
 
-    def get_default_session_timeout(self):
-        # type: () -> int
+    def get_default_session_timeout(self) -> int:
         return m2.ssl_get_default_session_timeout(self.ssl)
 
-    def get_socket_read_timeout(self):
-        # type: () -> timeout
+    def get_socket_read_timeout(self) -> timeout:
         return timeout.struct_to_timeout(
             self.socket.getsockopt(
                 socket.SOL_SOCKET,
@@ -694,13 +659,11 @@ class Connection(object):
             )
         )
 
-    @staticmethod
-    def _hexdump(s):
-        assert isinstance(s, bytes)
-        return ":".join(s)
+    # @staticmethod
+    # def _hexdump(s: bytes) -> bytes:
+    #     return b":".join(s)
 
-    def get_socket_write_timeout(self):
-        # type: () -> timeout
+    def get_socket_write_timeout(self) -> timeout:
         binstr = self.socket.getsockopt(
             socket.SOL_SOCKET,
             socket.SO_SNDTIMEO,
@@ -712,15 +675,13 @@ class Connection(object):
         #       (self._hexdump(binstr), timeo.sec, timeo.microsec))
         return timeo
 
-    def set_socket_read_timeout(self, timeo):
-        # type: (timeout) -> None
+    def set_socket_read_timeout(self, timeo: timeout) -> None:
         assert isinstance(timeo, timeout.timeout)
         self.socket.setsockopt(
             socket.SOL_SOCKET, socket.SO_RCVTIMEO, timeo.pack()
         )
 
-    def set_socket_write_timeout(self, timeo):
-        # type: (timeout) -> None
+    def set_socket_write_timeout(self, timeo: timeout) -> None:
         assert isinstance(timeo, timeout.timeout)
         binstr = timeo.pack()
         # print("Debug: set_socket_write_timeout: "
@@ -730,25 +691,21 @@ class Connection(object):
             socket.SOL_SOCKET, socket.SO_SNDTIMEO, binstr
         )
 
-    def get_version(self):
-        # type: () -> str
+    def get_version(self) -> str:
         """Return the TLS/SSL protocol version for this connection."""
         return m2.ssl_get_version(self.ssl)
 
     def set_post_connection_check_callback(
-        self, postConnectionCheck
-    ):  # noqa
-        # type: (Callable) -> None
+        self, postConnectionCheck: Callable
+    ) -> None:  # noqa
         self.postConnectionCheck = postConnectionCheck
 
-    def set_tlsext_host_name(self, name):
-        # type: (bytes) -> None
+    def set_tlsext_host_name(self, name: bytes) -> None:
         """Set the requested hostname for the SNI (Server Name Indication)
         extension.
         """
         m2.ssl_set_tlsext_host_name(self.ssl, name)
 
-    def set1_host(self, name):
-        # type: (bytes) -> None
+    def set1_host(self, name: bytes) -> None:
         """Set the requested hostname to check in the server certificate."""
         self.host = name
