@@ -8,7 +8,7 @@ and servers; HTTPS extensions to Python's httplib, urllib, and
 xmlrpclib; unforgeable HMAC'ing AuthCookies for web session
 management; FTP/TLS client and server; and ZSmime: An S/MIME
 messenger for Zope.  M2Crypto can also be used to provide SSL for
-Twisted. Smartcards supported through the Engine interface.
+Twisted.
 
 Copyright (c) 1999-2004 Ng Pheng Siong. All rights reserved.
 
@@ -17,10 +17,7 @@ Copyright (C) 2004-2007 OSAF. All Rights Reserved.
 
 Copyright 2008-2011 Heikki Toivonen. All rights reserved.
 """
-# noqa
-from typing import Any
-
-__version__: str = '0.44.0'
+__version__: str = '0.45.1'
 version: str = __version__
 
 try:
@@ -33,7 +30,7 @@ except ImportError:
 
 if Version is not None:
     version_info: tuple = (0, 0, 0)
-    __ver: Any = Version(__version__)
+    __ver: Version = Version(__version__)
     if hasattr(__ver, u'_version'):
         version_info = tuple(__ver._version[1])
     elif hasattr(__ver, u'version'):
