@@ -7,7 +7,6 @@ ASN1_String = NewType('ASN1_String', bytes)
 ASN1_Integer = NewType('ASN1_Integer', int)
 ASN1_Time = NewType('ASN1_Time', bytes)
 EC = NewType('EC', bytes)
-Engine = NewType('Engine', bytes)
-EC = NewType('EC', bytes)
 X509 = NewType('X509', bytes)
 X509_CRL = NewType('X509_CRL', bytes)
+X509_STORE_CTX = NewType('X509_STORE_CTX', bytes)
