@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 from __future__ import absolute_import
+
 """
 Unit tests for M2Crypto.BIO.
 
@@ -17,22 +18,51 @@ from tests.fips import fips_mode
 log = logging.getLogger('test_bio')
 
 ciphers = [
-    'des_ede_ecb', 'des_ede_cbc', 'des_ede_cfb', 'des_ede_ofb',
-    'des_ede3_ecb', 'des_ede3_cbc', 'des_ede3_cfb', 'des_ede3_ofb',
-    'aes_128_ecb', 'aes_128_cbc', 'aes_128_cfb', 'aes_128_ofb',
-    'aes_192_ecb', 'aes_192_cbc', 'aes_192_cfb', 'aes_192_ofb',
-    'aes_256_ecb', 'aes_256_cbc', 'aes_256_cfb', 'aes_256_ofb']
-nonfips_ciphers = ['bf_ecb', 'bf_cbc', 'bf_cfb', 'bf_ofb',
-                   # 'idea_ecb', 'idea_cbc', 'idea_cfb', 'idea_ofb',
-                   'cast5_ecb', 'cast5_cbc', 'cast5_cfb', 'cast5_ofb',
-                   # 'rc5_ecb', 'rc5_cbc', 'rc5_cfb', 'rc5_ofb',
-                   'des_ecb', 'des_cbc', 'des_cfb', 'des_ofb',
-                   'rc4', 'rc2_40_cbc']
-if not fips_mode and m2.OPENSSL_VERSION_NUMBER < 0x30000000:  # Forbidden ciphers
+    'des_ede_ecb',
+    'des_ede_cbc',
+    'des_ede_cfb',
+    'des_ede_ofb',
+    'des_ede3_ecb',
+    'des_ede3_cbc',
+    'des_ede3_cfb',
+    'des_ede3_ofb',
+    'aes_128_ecb',
+    'aes_128_cbc',
+    'aes_128_cfb',
+    'aes_128_ofb',
+    'aes_192_ecb',
+    'aes_192_cbc',
+    'aes_192_cfb',
+    'aes_192_ofb',
+    'aes_256_ecb',
+    'aes_256_cbc',
+    'aes_256_cfb',
+    'aes_256_ofb',
+]
+nonfips_ciphers = [
+    'bf_ecb',
+    'bf_cbc',
+    'bf_cfb',
+    'bf_ofb',
+    # 'idea_ecb', 'idea_cbc', 'idea_cfb', 'idea_ofb',
+    'cast5_ecb',
+    'cast5_cbc',
+    'cast5_cfb',
+    'cast5_ofb',
+    # 'rc5_ecb', 'rc5_cbc', 'rc5_cfb', 'rc5_ofb',
+    'des_ecb',
+    'des_cbc',
+    'des_cfb',
+    'des_ofb',
+    'rc4',
+    'rc2_40_cbc',
+]
+if (
+    not fips_mode and m2.OPENSSL_VERSION_NUMBER < 0x30000000
+):  # Forbidden ciphers
     ciphers += nonfips_ciphers
 
 
-
 class CipherStreamTestCase(unittest.TestCase):
     def try_algo(self, algo):
         data = b'123456789012345678901234'
@@ -64,8 +94,9 @@ class CipherStreamTestCase(unittest.TestCase):
         with self.assertRaises(IOError):
             cf.readlines()
 
-        self.assertEqual(data, data2,
-                         '%s algorithm cipher test failed' % algo)
+        self.assertEqual(
+            data, data2, '%s algorithm cipher test failed' % algo
+        )
 
     def test_algo(self):
         for algo in ciphers:
@@ -78,7 +109,9 @@ class CipherStreamTestCase(unittest.TestCase):
 
 
 def suite():
-    return unittest.TestLoader().loadTestsFromTestCase(CipherStreamTestCase)
+    return unittest.TestLoader().loadTestsFromTestCase(
+        CipherStreamTestCase
+    )
 
 
 if __name__ == '__main__':
