@@ -4,51 +4,49 @@
 
 Copyright (c) 2000 Ng Pheng Siong. All rights reserved."""
 
-RCS_id='$Id: test_bio_iobuf.py 299 2005-06-09 17:32:28Z heikki $'
+from io import BytesIO
 
-from cStringIO import StringIO
-
-import unittest
-import M2Crypto
 from M2Crypto.BIO import IOBuffer, MemoryBuffer
+from tests import unittest
+
 
 class IOBufferTestCase(unittest.TestCase):
 
     def setUp(self):
-        self._data = 'abcdef\n'
+        self._data = b'abcdef\n'
         self.data = self._data * 1024
 
     def tearDown(self):
         pass
 
-    def check_init_empty(self):
+    def test_init_empty(self):
         mb = MemoryBuffer()
         io = IOBuffer(mb)
         out = io.read()
-        assert out == ''
+        self.assertEqual(out, b'')
 
-    def check_init_something(self):
+    def test_init_something(self):
         mb = MemoryBuffer(self.data)
         io = IOBuffer(mb)
         out = io.read(len(self.data))
-        assert out == self.data
+        self.assertEqual(out, self.data)
 
-    def check_read_less_than(self):
+    def test_read_less_than(self):
         chunk = len(self.data) - 7
         mb = MemoryBuffer(self.data)
         io = IOBuffer(mb)
         out = io.read(chunk)
-        assert out == self.data[:chunk]
-        
-    def check_read_more_than(self):
+        self.assertEqual(out, self.data[:chunk])
+
+    def test_read_more_than(self):
         chunk = len(self.data) + 8
         mb = MemoryBuffer(self.data)
         io = IOBuffer(mb)
         out = io.read(chunk)
-        assert out == self.data
+        self.assertEqual(out, self.data)
 
-    def check_readline(self):
-        buf = StringIO()
+    def test_readline(self):
+        buf = BytesIO()
         mb = MemoryBuffer(self.data)
         io = IOBuffer(mb)
         while 1:
@@ -56,37 +54,40 @@ class IOBufferTestCase(unittest.TestCase):
             if not out:
                 break
             buf.write(out)
-            assert out == self._data
-        assert buf.getvalue() == self.data
+            self.assertEqual(out, self._data)
+        self.assertEqual(buf.getvalue(), self.data)
 
-    def check_readlines(self):
-        buf = StringIO()
+    def test_readlines(self):
+        buf = BytesIO()
         mb = MemoryBuffer(self.data)
         io = IOBuffer(mb)
         lines = io.readlines()
         for line in lines:
-            assert line == self._data
+            self.assertEqual(line, self._data)
             buf.write(line)
-        assert buf.getvalue() == self.data
+        self.assertEqual(buf.getvalue(), self.data)
 
-    def check_closed(self):
+    def test_closed(self):
         mb = MemoryBuffer(self.data)
         io = IOBuffer(mb)
         io.close()
-        self.assertRaises(IOError, io.write, self.data)
+        with self.assertRaises(IOError):
+            io.write(self.data)
         assert not io.readable() and not io.writeable()
 
-    def check_read_only(self):
+    def test_read_only(self):
         mb = MemoryBuffer(self.data)
         io = IOBuffer(mb, mode='r')
-        self.assertRaises(IOError, io.write, self.data)
+        with self.assertRaises(IOError):
+            io.write(self.data)
         assert not io.writeable()
 
 
 def suite():
-    return unittest.makeSuite(IOBufferTestCase, 'check_')
-    
+    return unittest.TestLoader().loadTestsFromTestCase(
+        IOBufferTestCase
+    )
+
 
 if __name__ == '__main__':
     unittest.TextTestRunner().run(suite())
-
