@@ -44,10 +44,15 @@ class HandshakeClient(threading.Thread):
         while not handshake_complete:
             ret = sslbio.do_handshake()
             if ret <= 0:
-                if not sslbio.should_retry() or not sslbio.should_read():
+                if (
+                    not sslbio.should_retry()
+                    or not sslbio.should_read()
+                ):
                     err_string = Err.get_error()
                     print(err_string)
-                    sys.exit("unrecoverable error in handshake - client")
+                    sys.exit(
+                        "unrecoverable error in handshake - client"
+                    )
                 else:
                     output_token = writebio.read()
                     if output_token is not None:
@@ -135,8 +140,13 @@ class SSLTestCase(unittest.TestCase):
 
             ret = self.sslbio.do_handshake()
             if ret <= 0:
-                if not self.sslbio.should_retry() or not self.sslbio.should_read():
-                    sys.exit("unrecoverable error in handshake - server")
+                if (
+                    not self.sslbio.should_retry()
+                    or not self.sslbio.should_read()
+                ):
+                    sys.exit(
+                        "unrecoverable error in handshake - server"
+                    )
             else:
                 handshake_complete = True
 
