@@ -28,12 +28,15 @@ class ECDSATestCase(unittest.TestCase):
     data = hashlib.sha1(b'Can you spell subliminal channel?').digest()
 
     def setUp(self):
-        assert os.path.exists(self.errkey) and os.access(self.errkey, os.R_OK), \
-            "Cannot access errkey file {}".format(self.errkey)
-        assert os.path.exists(self.privkey) and os.access(self.privkey, os.R_OK), \
-            "Cannot access privkey file {}".format(self.privkey)
-        assert os.path.exists(self.pubkey) and os.access(self.pubkey, os.R_OK), \
-            "Cannot access pubkey file {}".format(self.pubkey)
+        assert os.path.exists(self.errkey) and os.access(
+            self.errkey, os.R_OK
+        ), "Cannot access errkey file {}".format(self.errkey)
+        assert os.path.exists(self.privkey) and os.access(
+            self.privkey, os.R_OK
+        ), "Cannot access privkey file {}".format(self.privkey)
+        assert os.path.exists(self.pubkey) and os.access(
+            self.pubkey, os.R_OK
+        ), "Cannot access pubkey file {}".format(self.pubkey)
 
     def callback(self, *args):
         pass
